@@ -18,10 +18,11 @@ def rk_within_day_directions(
     **kwargs,
 ) -> pd.DataFrame:
     """
-    Method to get directions for rk within day
+    The predicted probability of any given hour is up(UP), down(DOWN) or no direction(NONE).
+
     Parameters:
         start: Start timestamp
-        end: end timestamp
+        end: End timestamp
         price_area: Price area
         ref_dt: Reference timestamp
         access_token: Access token
@@ -55,10 +56,13 @@ def rk_within_day_distributions(
     **kwargs,
 ) -> pd.DataFrame:
     """
-    Method to get distributions for rk within day
+    The predicted imbalance price distribution.
+
+    In the response, spread is defined as the difference between the RK price and the spot price (priceRK - pricespot).
+
     Parameters:
         start: Start timestamp
-        end: end timestamp
+        end: End timestamp
         price_area: Price area
         ref_dt: Reference timestamp
         access_token: Access token
@@ -94,10 +98,11 @@ def rk_within_day_large_up_fps(  # pylint: disable=too-many-arguments
     **kwargs,
 ) -> pd.DataFrame:
     """
-    Method to get large up for rk within day
+    Indicator for whether a given hour will experience a large up RK price.
+
     Parameters:
         start: Start timestamp
-        end: end timestamp
+        end: End timestamp
         price_area: Price area
         large_price_level: Large price level
         ref_dt: Reference timestamp
@@ -137,7 +142,8 @@ def rk_within_day_large_down_fps(  # pylint: disable=too-many-arguments
     **kwargs,
 ) -> pd.DataFrame:
     """
-    Method to get large down for rk within day
+    Indicator for whether a given hour will experience a large down RK price.
+
     Parameters:
         start: Start timestamp
         end: end timestamp
@@ -179,7 +185,9 @@ def rk_comparison_by_price(
     **kwargs,
 ) -> pd.DataFrame:
     """
-    Method to get probability for rk within day in comparison to provided price
+    Get the probability of the RK price being less than or equal to the user specified reference price for each hour
+    between start and end (inclusive).
+
     Parameters:
         start: Start timestamp
         end: End timestamp
